==> apache-tinkerpop-3.3.8-src.zip: tinkerpop-3.3.8/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/kryoshim/KryoShim.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.structure.io.gryo.kryoshim;

/**
 * A minimal {@link org.apache.tinkerpop.shaded.kryo.Kryo}-like abstraction.
 * See that class for method documentation.
 *
 * @param <I> this interface's complementary InputShim
 * @param <O> this interface's complementary OutputShim
 */
public interface KryoShim<I extends InputShim, O extends OutputShim> {

    public <T> T readObject(final I input, final Class<T> type);

    public Object readClassAndObject(final I input);

    public void writeObject(final O output, final Object object);

    public void writeClassAndObject(final O output, final Object object);

    public <T> T readObjectOrNull(final I input, final Class<T> type);

    public void writeObjectOrNull(final O output, final Object object, final Class type);
}

==> apache-tinkerpop-3.7.5-src.zip: tinkerpop-3.7.5/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/kryoshim/KryoShim.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.structure.io.gryo.kryoshim;

import org.apache.tinkerpop.shaded.kryo.Kryo;

/**
 * A minimal {@link Kryo}-like abstraction.  See that class for method documentation.
 *
 * @param <I> this interface's complementary InputShim
 * @param <O> this interface's complementary OutputShim
 */
public interface KryoShim<I extends InputShim, O extends OutputShim> {

    public <T> T readObject(final I input, final Class<T> type);

    public Object readClassAndObject(final I input);

    public void writeObject(final O output, final Object object);

    public void writeClassAndObject(final O output, final Object object);

    public <T> T readObjectOrNull(final I input, final Class<T> type);

    public void writeObjectOrNull(final O output, final Object object, final Class type);
}
